==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>جميع الخطوط</translation>
    </message>
    <message>
        <source>System</source>
        <translation>النظام</translation>
    </message>
    <message>
        <source>User</source>
        <translation>المستخدم</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>الفعالة</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>اللغة الصينية</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>الخطوط أحادية المسافة</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>إلغاء</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>حذف</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>تفعيل</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>تعطيل</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>ملف معطوب</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>نفس الخط مثبت مسبقاً</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>خط النظام</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/ </translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>إعلى الصفحة</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>أسفل الصفحة</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation> Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation> Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 خط مثبت</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 خط مثبت</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished">ملف معطوب</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>هذا الخط لن يكون متاح للبرامج</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>هذه الخطوط لن تكون متاحة للبرامج</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>حذف</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>يتم حذف الخطوط، الرجاء الانتظار... </translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>التحقق من الخط</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>لا توجد خطوط ليتم تثبيتها</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">خروج</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">تأكيد</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>المعلومات الأساسية</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>الأسلوب</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>الإصدار</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>غير معروف</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>الاسم الكامل</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>اسم الـ Ps</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>العلامة التجارية</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>مدير الخطوط</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>مدير الخطوط يساعد المستخدمين لتثبيت وإدارة الخطوط.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>جاي تحميل الخطوط، نرجوا الإنتظار...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>تم تصدير الخط إلى سطح المكتب</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>تم تصدير %1 خط/خطوط إلى سطح المكتب</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>إضافة خط</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>تفعيل</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>تعطيل</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>غير المفضلة</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>العرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>تصدير</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>معطّلة</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>تم تعطيل الخطوط</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>تثبيت خط</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>جاري التحقق...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>غير معروف</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>ملف معطوب</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>تم التثبيت</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>غير مثبّت</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>تثبيت خط</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>البحث</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>لا يوجد نتائج لبحثك</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>لا يوجد خطوط</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>عرض الإختصارات</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>أعلى الصفحة</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>أسفل الصفحة</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>إضافة خط</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>غير المفضلة</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>معلومات الخط</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>أدخل معاينة النص</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.15.tar.xz: BUILD/translations/deepin-font-manager_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>جميع الخطوط</translation>
    </message>
    <message>
        <source>System</source>
        <translation>النظام</translation>
    </message>
    <message>
        <source>User</source>
        <translation>المستخدم</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>الفعالة</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>اللغة الصينية</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>الخطوط أحادية المسافة</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>إلغاء</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>٪1 هو يعتبر عائلة خطوط ، في حالة المتابعة سيتم حذف جميع الخطوط الموجودة في هذه العائلة</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>حذف</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>٪1 هو يعتبر عائلة خطوط ، في حالة المتابعة سيتم تفعيل جميع الخطوط الموجودة في هذه العائلة</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>٪1 هو يعتبر عائلة خطوط ، في حالة المتابعة سيتم تعطيل جميع الخطوط الموجودة في هذه العائلة</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>تفعيل</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>تعطيل</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>تطبيق على جميع عائلات الخطوط المحددة</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>ملف معطوب</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>نفس الخط مثبت مسبقاً</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>خط النظام</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/ </translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>إعلى الصفحة</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>أسفل الصفحة</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation> Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation> Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 خط مثبت</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 خط مثبت</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>فشل تثبيت الخط 1% ، لا توجد مساحة كافية على القرص.</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>فشل تثبيت الخطوط 1% ، لا توجد مساحة كافية على القرص.</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>الخطوط</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>ملف معطوب</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>هذا الخط لن يكون متاح للبرامج</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>هذه الخطوط لن تكون متاحة للبرامج</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>لا يمكن الحذف نظراً لأن ٪1 تعتبر من خطوط النظام</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>لا يمكن الحذف الخط &quot;1%&quot; لأنه قيد الاستخدام</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>لا يمكن الحذف نظراً لأن  ٪1 تعتبر من خطوط النظام، بالإضافة إلى أن الخط &quot;٪2&quot; قيد الاستخدام حالياً</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>هل أنت متأكد من أنك تريد حذف الخط (الخطوط) 1% ؟</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>حذف</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>يتم حذف الخطوط، الرجاء الانتظار... </translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>التحقق من الخط</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>لا توجد خطوط ليتم تثبيتها</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>خروج</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>تأكيد</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>لا تجعل أحلامك تكون أحلام فقط</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>المعلومات الأساسية</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>الأسلوب</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>النوع</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>الإصدار</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>الوصف</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>غير معروف</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>الاسم الكامل</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>اسم الـ Ps</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>العلامة التجارية</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>حق الطبع</translation>
    </message>
    <message>
        <source>License Description</source>
        <translation>وصف الترخيص</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>مدير الخطوط</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>مدير الخطوط يساعد المستخدمين لتثبيت وإدارة الخطوط.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>جاي تحميل الخطوط، نرجوا الإنتظار...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>تم تصدير الخط إلى سطح المكتب</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>تم تصدير %1 خط/خطوط إلى سطح المكتب</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>فشل تصدير الخط 1% ، لا توجد مساحة كافية على القرص.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>فشل تصدير الخطوط 1% ، لا توجد مساحة كافية على القرص.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>إضافة خط</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>تفعيل</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>تعطيل</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>غير المفضلة</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>التفاصيل</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>العرض في مدير الملفات</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>تصدير</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>معطّلة</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>تم تعطيل الخطوط</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>لا يمكن تعطيل 1% لأنه قيد الاستخدام</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>لا يمكن تعطيل خطوط النظام و الخطوط التي قيد الاستخدام</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>لا يمكن تعطيل خطوط النظام</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>تثبيت خط</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>جاري التحقق...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>غير معروف</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>ملف معطوب</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>تم التثبيت</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>غير مثبّت</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>تثبيت خط</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>البحث</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>لا يوجد نتائج لبحثك</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>لا يوجد خطوط</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>عرض الإختصارات</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>أعلى الصفحة</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>أسفل الصفحة</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>إضافة خط</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>غير المفضلة</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>معلومات الخط</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>أدخل معاينة النص</translation>
    </message>
</context>
</TS>
